const router = require("express").Router();
const User = require("../models/User");
const { authValidation } = require("../validation");
const bcrypt = require("bcryptjs");
const jwt = require("jsonwebtoken");

router.post("/register", async (req, res) => {
  const { error, value } = authValidation(req.body);
  if (error)
    return res
      .status(400)
      .json({ success: false, message: error.details[0].message });

  const userExists = await User.findOne({ username: value.username });
  if (userExists)
    return res.status(400).json({
      success: false,
      message: `${value.username} already exists`,
    });

  const salt = await bcrypt.genSalt(10);
  const hashedPassword = await bcrypt.hash(value.password, salt);

  const user = new User({
    username: value.username,
    password: hashedPassword,
  });
  try {
    const savedUser = await user.save();
    res.status(200).send({
      id: savedUser._id,
      username: savedUser.username,
    });
  } catch (err) {
    res.status(400).send(err);
  }
});

router.post("/login", async (req, res) => {
  const { error, value } = authValidation(req.body);
  if (error)
    return res
      .status(400)
      .json({ success: false, message: error.details[0].message });

  const user = await User.findOne({ username: value.username });
  if (!user)
    return res.status(400).json({
      success: false,
      message: `${value.username} does not exist`,
    });

  const validPass = await bcrypt.compare(req.body.password, user.password);
  if (!validPass)
    return res
      .status(400)
      .json({ success: false, message: "Invalid Password" });

  const token = jwt.sign({ _id: user._id }, process.env.tokensecret);

  return res
    .header("authtoken", token)
    .status(200)
    .json({
      success: true,
      message: `${user.username} has authenticated`,
      username: user.username,
    });
});

module.exports = router;
