const router = require("express").Router();
const MsgAuth = require("../models/MsgAuth");
const Bnums = require("../models/Bnums");
const jwt = require("jsonwebtoken");
const msger = require("@tls/messaging");
const authConfig = require("../authConfig");
const { numberValidation } = require("../validation");

router.post("/addlocal", async (req, res) => {
  const { error, value } = numberValidation(req.body);
  if (error)
    return res
      .status(400)
      .json({ success: false, message: error.details[0].message });

  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    const findExisting = await Bnums.find({ userId: thetoken._id });

    if (creds.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no secrets have been configured yet!",
      });
    }

    const validatedNum = {
      number: value.number,
    };

    if (findExisting.length === 0) {
      const addBnums = new Bnums(validatedNum);
      addBnums.userId = creds[0].userId;
      await addBnums.save();
    } else {
      const numberToAdd = value;
      const numbersInDB = await Bnums.find({ userId: thetoken._id });

      const numberCheck = await Bnums.find({ bnum: value.number });
      if (numberCheck.length === 1)
        return res.status(400).json({
          success: false,
          message: `${value.number} already exists`,
        });

      numbersInDB[0].bnum.push(numberToAdd.number);

      const updatedNums = await Bnums.findOneAndUpdate(
        { userId: thetoken._id },
        { bnum: numbersInDB[0].bnum },
        {
          new: true,
          runValidators: true,
        }
      );
      res.status(200).json({
        success: true,
        message: updatedNums,
      });
    }
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

router.get("/getlocal", async (req, res) => {
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    if (creds.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no secrets have been configured yet!",
      });
    }

    const getNumbers = await Bnums.find({ userId: thetoken._id });

    if (getNumbers.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no numbers exist in the db for this user!",
      });
    }

    res.status(200).json({ success: true, message: getNumbers });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

router.get("/getremote", async (req, res) => {
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    if (creds.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no secrets have been configured yet!",
      });
    }

    msger.CONFIG.setConfig(authConfig(creds));
    const bnum = msger.BNUM.getInstance();
    const getBnums = await bnum.get();
    const findExisting = await Bnums.find({ userId: thetoken._id });

    if (findExisting.length === 0) {
      const addBnums = new Bnums(getBnums);
      addBnums.userId = creds[0].userId;
      await addBnums.save();
    } else {
      await Bnums.findOneAndUpdate({ userId: thetoken._id }, getBnums, {
        new: true,
        runValidators: true,
      });
    }

    if (getBnums && getBnums.message) {
      const checkFail = getBnums.message.includes("fail");
      if (checkFail)
        return res
          .status(400)
          .json({ success: false, message: getBnums.message });
    }

    res.status(200).json({ success: true, message: getBnums });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

router.get("/register", async (req, res) => {
  // this one is danger for trial accounts, you can only add 5 and you can't change the numbers you add
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    if (creds.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no secrets have been configured yet!",
      });
    }

    msger.CONFIG.setConfig(authConfig(creds));
    const findBnums = await Bnums.find({ userId: thetoken._id });

    if (findBnums.length === 0) {
      throw { message: "the userid doesn't exist" };
    } else if (findBnums[0].bnum.length === 0) {
      throw { message: "user exists, but no bnums for registration" };
    } else if (findBnums[0].bnum.length > 5) {
      throw { message: "too many bnums for registration" };
    }

    const data = {
      bnum: findBnums[0].bnum,
    };

    const bnumRegister = msger.BNUM.getInstance();
    const registeredBnums = await bnumRegister.register(data);

    if (registeredBnums && registeredBnums.message) {
      const checkFail = registeredBnums.message.includes("fail");
      if (checkFail) {
        throw { message: registeredBnums.message };
      }
    }

    res.status(200).json({ success: true, message: registeredBnums });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

router.delete("/delete", async (req, res) => {
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    const numberToDelete = req.body.number;
    const numbersInDB = await Bnums.find({ userId: thetoken._id });
    const newNumbers = numbersInDB[0].bnum.pull(numberToDelete);
    await Bnums.findOneAndUpdate(
      { userId: thetoken._id },
      { bnum: newNumbers },
      {
        new: true,
        runValidators: true,
      }
    );

    res.status(200).json({
      success: true,
      message: `${numberToDelete} was deleted!`,
    });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

module.exports = router;
