const router = require("express").Router();
const MsgAuth = require("../models/MsgAuth");
const Sms = require("../models/Sms");
const jwt = require("jsonwebtoken");
const msger = require("@tls/messaging");
const authConfig = require("../authConfig");
const { smsValidation } = require("../validation");

router.post("/send", async (req, res) => {
  const { error, value } = smsValidation(req.body);
  if (error)
    return res
      .status(400)
      .json({ success: false, message: error.details[0].message });

  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    if (creds.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no secrets have been configured yet!",
      });
    }

    msger.CONFIG.setConfig(authConfig(creds));

    const smsData = req.body;
    const addSms = new Sms(smsData);
    addSms.userId = creds[0].userId;

    const validatedData = {
      to: value.to,
      body: value.body,
    };

    const smsSender = msger.SMS.getInstance();
    const smsResponse = await smsSender.send(validatedData);

    if (smsResponse && smsResponse.message) {
      const checkFail = smsResponse.message.includes("fail");
      if (checkFail) {
        return res.status(400).json({
          success: false,
          message: smsResponse.message,
        });
      }
    }

    addSms.deliveryStatus = smsResponse.messages[0].deliveryStatus;
    addSms.messageId = smsResponse.messages[0].messageId;
    addSms.messageType = smsResponse.messageType;
    addSms.numberSegments = smsResponse.numberSegments;
    const savedSms = await addSms.save();

    res.status(200).json({ success: true, message: savedSms });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

router.post("/updatestatus", async (req, res) => {
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });
    msger.CONFIG.setConfig(authConfig(creds));

    const smsData = req.body;
    const findExisting = await Sms.find({
      messageId: req.body.messageId,
      userId: thetoken._id,
    });

    if (findExisting.length === 0) {
      throw { message: `no msg matching ${req.body.messageId}` };
    }

    const smsSender = msger.SMS.getInstance();
    const smsResponse = await smsSender.status(req.body.messageId);

    const updatedSMS = await Sms.findOneAndUpdate(
      { messageId: req.body.messageId, userId: thetoken._id },
      smsResponse[0],
      {
        new: true,
        runValidators: true,
      }
    );

    res.status(200).json({ success: true, message: updatedSMS });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

router.get("/getmsgs", async (req, res) => {
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    const getMsgs = await Sms.find({ userId: thetoken._id });

    if (getMsgs.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no sent msgs exist in the db for this user!",
      });
    }

    res.status(200).json({ success: true, message: getMsgs });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

module.exports = router;
