const router = require("express").Router();
const MsgAuth = require("../models/MsgAuth");
const Subscription = require("../models/Subscription");
const jwt = require("jsonwebtoken");
const msger = require("@tls/messaging");
const authConfig = require("../authConfig");

router.get("/getlocal", async (req, res) => {
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    const findExisting = await Subscription.find({ userId: thetoken._id });

    res.status(200).json({ success: true, message: findExisting });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

router.get("/getremote", async (req, res) => {
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    if (creds.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no secrets have been configured yet!",
      });
    }

    msger.CONFIG.setConfig(authConfig(creds));
    const sub = msger.Subscription.getInstance();
    const getSub = await sub.get({});
    const findExisting = await Subscription.find({ userId: thetoken._id });

    // #11
    // needs investigation here, if getSub fails it still reports 200 OK but says 401 fail
    // might have that mixed, will check later.

    if (getSub && getSub.message) {
      const checkFail = getSub.message.includes("fail");
      if (checkFail) {
        throw { message: getSub.message };
      }
    }

    if (findExisting.length === 0) {
      const addSub = new Subscription(getSub);
      addSub.userId = creds[0].userId;
      await addSub.save();
    } else {
      await Subscription.findOneAndUpdate(thetoken._id, getSub, {
        new: true,
        runValidators: true,
      });
    }
    res.status(200).json({ success: true, message: getSub });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

router.get("/new", async (req, res) => {
  try {
    thetoken = jwt.verify(req.headers.authtoken, process.env.tokensecret);
    const creds = await MsgAuth.find({
      userId: thetoken._id,
    });

    if (creds.length === 0) {
      return res.status(400).json({
        success: false,
        message: "no secrets have been configured yet!",
      });
    }

    msger.CONFIG.setConfig(authConfig(creds));
    const sub = msger.Subscription.getInstance();
    const createSub = await sub.create({});
    const findExisting = await Subscription.find({ userId: thetoken._id });

    if (createSub && createSub.message) {
      const checkFail = createSub.message.includes("fail");
      if (checkFail) {
        throw { message: createSub.message };
      }
    }

    if (findExisting.length === 0) {
      const addSub = new Subscription(createSub);
      addSub.userId = creds[0].userId;
      await addSub.save();
    } else {
      await Subscription.findOneAndUpdate(thetoken._id, createSub, {
        new: true,
        runValidators: true,
      });
    }
    res.status(200).json({ success: true, message: createSub });
  } catch (err) {
    res.status(400).json({ success: false, message: err.message });
  }
});

module.exports = router;
