const Joi = require("@hapi/joi");
const myCustomJoi = Joi.extend(require("joi-phone-number"));

const authValidation = (data) => {
  const schema = Joi.object({
    username: Joi.string()
      .min(2)
      .max(20)
      .required()
      .trim()
      .lowercase()
      .alphanum(),

    password: Joi.string().min(6).max(1024).required(),
  });
  return schema.validate(data);
};

const secretValidation = (data) => {
  const schema = Joi.object({
    clientId: Joi.string().min(6).max(1024).required(),
    clientSecret: Joi.string().min(6).max(1024).required(),
  });
  return schema.validate(data);
};

const numberValidation = (data) => {
  const schema = Joi.object({
    number: myCustomJoi
      .string()
      .required()
      .phoneNumber({ defaultCountry: "AU", format: "e164", strict: true }),
  });
  return schema.validate(data);
};

const smsValidation = (data) => {
  const schema = Joi.object({
    to: myCustomJoi
      .string()
      .required()
      .phoneNumber({ defaultCountry: "AU", format: "e164", strict: true }),
    body: Joi.string().min(1).max(150).required(),
  });

  return schema.validate(data);
};

module.exports.authValidation = authValidation;
module.exports.secretValidation = secretValidation;
module.exports.numberValidation = numberValidation;
module.exports.smsValidation = smsValidation;
