import React, { useState, useEffect } from "react";
import Authentication from "./components/Authentication";
import useToken from "./components/useToken";
import Appbar from "./components/Appbar";
import Box from "@material-ui/core/Box";
import Typography from "@material-ui/core/Typography";
import useMyStyles from "./components/useStyles";
import { Divider } from "@material-ui/core";
import Paper from "@material-ui/core/Paper";
import Grid from "@material-ui/core/Grid";
import SimpleTabs from "./components/SimpleTabs";
import {
  getlocalContacts,
  getSubLocal,
  getSentMsgs,
} from "./components/APIHelper";

const Home = () => {
  const { token, setToken } = useToken();
  const classes = useMyStyles();
  const [sms, setSms] = useState([]);
  const [sub, setSub] = useState([]);
  const [contacts, setContacts] = useState([]);
  const [sentmsg, setSentmsg] = useState([]);

  useEffect(() => {
    loadContacts();
    getSub();
    SentMsgs();
  }, [token]);

  const loadContacts = async () => {
    const localContactsResponse = await getlocalContacts();
    if (localContactsResponse.status === 200) {
      setContacts(localContactsResponse.data.message[0].bnum);
    }
  };

  const getSub = async () => {
    const localSubResponse = await getSubLocal();
    if (localSubResponse.status === 200) {
      setSub(localSubResponse.data.message[0]);
    }
  };

  const SentMsgs = async () => {
    const msgResponse = await getSentMsgs();
    console.log(msgResponse);
    if (msgResponse.status === 200) {
      setSentmsg(msgResponse.data.message);
    }
  };

  if (!token) {
    return <Authentication setToken={setToken} />;
  } else {
    return (
      <div className={classes.root}>
        <Appbar
          classes={classes}
          setToken={setToken}
          setSms={setSms}
          setSub={setSub}
          setContacts={setContacts}
          setSentmsg={setSentmsg}
        />
        <Grid container spacing={3}>
          <Grid item xs={12}>
            <Box m={2}>
              <Typography variant="subtitle1" gutterBottom>
                A simple application to send SMS messages.
              </Typography>
            </Box>
            <Divider />
          </Grid>

          <Grid item xs={12}>
            <SimpleTabs
              classes={classes}
              sms={sms}
              setSms={setSms}
              sub={sub}
              setSub={setSub}
              contacts={contacts}
              setContacts={setContacts}
              sentmsg={sentmsg}
              setSentmsg={setSentmsg}
            />
          </Grid>
        </Grid>
      </div>
    );
  }
};

export default Home;
