import axios from 'axios';

const API_URL = `${process.env.REACT_APP_APIURL}`;

const showErrors = (err) => {
  if (err.response) {
    const error = {
      success: false,
      message: err.response.data.message,
      failure: 'server says no',
    };

    return error;
  } else if (err.request) {
    const error = {
      success: false,
      message: err.request,
      failure: 'client says no',
    };

    return error;
  } else console.log(err);
};

export const userLogin = async (data) => {
  try {
    const loginResponse = await axios.post(`${API_URL}/api/user/login`, data);
    return loginResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const userRegister = async (data) => {
  try {
    const registerResponse = await axios.post(
      `${API_URL}/api/user/register`,
      data
    );
    return registerResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const userSecrets = async (data) => {
  try {
    let token = localStorage.getItem('jwt');
    const secretResponse = await axios.post(
      `${API_URL}/api/msgauth/login`,
      data,
      {
        headers: { authtoken: token },
      }
    );
    return secretResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const createSub = async () => {
  try {
    let token = localStorage.getItem('jwt');
    const subcreateResponse = await axios.get(`${API_URL}/api/sub/new`, {
      headers: { authtoken: token },
    });
    return subcreateResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const getSubLocal = async () => {
  try {
    let token = localStorage.getItem('jwt');
    const subLocalResponse = await axios.get(`${API_URL}/api/sub/getlocal`, {
      headers: { authtoken: token },
    });
    return subLocalResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const getSubRemote = async () => {
  try {
    let token = localStorage.getItem('jwt');
    const subRemoteResponse = await axios.get(`${API_URL}/api/sub/getremote`, {
      headers: { authtoken: token },
    });
    return subRemoteResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const getlocalContacts = async () => {
  try {
    let token = localStorage.getItem('jwt');
    const contactLocalResponse = await axios.get(
      `${API_URL}/api/bnum/getlocal`,
      {
        headers: { authtoken: token },
      }
    );
    return contactLocalResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const getremoteContacts = async () => {
  try {
    let token = localStorage.getItem('jwt');
    const contactRemoteResponse = await axios.get(
      `${API_URL}/api/bnum/getremote`,
      {
        headers: { authtoken: token },
      }
    );
    return contactRemoteResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const delContact = async (contact) => {
  try {
    let token = localStorage.getItem('jwt');

    const data = {
      number: contact,
    };
    const headers = {
      authtoken: token,
    };

    const delNumResponse = await axios.delete(`${API_URL}/api/bnum/delete`, {
      headers,
      data,
    });
    return delNumResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const addContact = async (contact) => {
  try {
    let token = localStorage.getItem('jwt');
    const addNumResponse = await axios.post(
      `${API_URL}/api/bnum/addlocal`,
      contact,
      {
        headers: { authtoken: token },
      }
    );
    return addNumResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const registerContacts = async () => {
  try {
    let token = localStorage.getItem('jwt');
    const registerResponse = await axios.get(`${API_URL}/api/bnum/register`, {
      headers: { authtoken: token },
    });
    return registerResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const sendMessage = async (data) => {
  try {
    let token = localStorage.getItem('jwt');
    const registerResponse = await axios.post(`${API_URL}/api/sms/send`, data, {
      headers: { authtoken: token },
    });
    return registerResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};

export const getSentMsgs = async () => {
  try {
    let token = localStorage.getItem('jwt');
    const sentmsgResponse = await axios.get(`${API_URL}/api/sms/getmsgs`, {
      headers: { authtoken: token },
    });
    return sentmsgResponse;
  } catch (err) {
    const errors = showErrors(err);
    return errors;
  }
};
