import React from "react";
import AppBar from "@material-ui/core/AppBar";
import Toolbar from "@material-ui/core/Toolbar";
import Container from "@material-ui/core/Container";
import Typography from "@material-ui/core/Typography";
import Box from "@material-ui/core/Box";
import Paper from "@material-ui/core/Paper";
import Tabs from "@material-ui/core/Tabs";
import Tab from "@material-ui/core/Tab";
import TextField from "@material-ui/core/TextField";
import Button from "@material-ui/core/Button";
import { userRegister, userLogin } from "./APIHelper";
import { useSnackbar } from "notistack";

const Authentication = (props) => {
  const { setToken } = props;
  const [authtype, setAuthtype] = React.useState(0);

  const handleChange = (event, newValue) => {
    setAuthtype(newValue);
  };

  return (
    <>
      <Box component="span" m={1}>
        <Container maxWidth="xs">
          <Paper>
            <AppBar position="static">
              <Toolbar>
                <Typography variant="h6">👋</Typography>
              </Toolbar>
            </AppBar>

            <Tabs
              value={authtype}
              indicatorColor="primary"
              textColor="primary"
              onChange={handleChange}
              aria-label="disabled tabs example"
              variant="fullWidth"
            >
              <Tab label="Login" />
              <Tab label="Register" />
            </Tabs>
          </Paper>
          <AuthenticationForm authtype={authtype} setToken={setToken} />
        </Container>
      </Box>
    </>
  );
};

const AuthenticationForm = (props) => {
  const { authtype, setToken } = props;
  const { enqueueSnackbar } = useSnackbar();

  const handleSnack = (message, variant) => {
    enqueueSnackbar(`${message}`, { variant });
  };

  const blankUser = {
    username: "",
    password: "",
  };

  const [newUser, setNewUser] = React.useState(blankUser);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setNewUser({ ...newUser, [name]: value });
  };

  return (
    <>
      <Box m={1}>
        <TextField
          id="filled-full-width"
          label="username"
          name="username"
          value={newUser.username}
          fullWidth
          margin="normal"
          InputLabelProps={{
            shrink: true,
          }}
          required
          onChange={handleChange}
        />
        <TextField
          id="standard-password-input"
          label="password"
          name="password"
          value={newUser.password}
          type="password"
          fullWidth
          margin="normal"
          InputLabelProps={{
            shrink: true,
          }}
          required
          onChange={handleChange}
        />
      </Box>
      <Box m={1}>
        <AuthButton
          authtype={authtype}
          data={newUser}
          handleSnack={handleSnack}
          setToken={setToken}
          setNewUser={setNewUser}
          blankUser={blankUser}
        />
      </Box>
    </>
  );
};

const AuthButton = (props) => {
  const { authtype, data, handleSnack, setToken } = props;
  let actionButton;

  const loginAction = async (e, data) => {
    e.preventDefault();
    const submittedLogin = await userLogin(data);

    if (submittedLogin.success === false) {
      handleSnack(submittedLogin.message, "error");
    } else if (submittedLogin.status === 200) {
      handleSnack(`login successful for ${data.username}`, "success");
      const token = submittedLogin.headers.authtoken;
      setToken(token);
      localStorage.setItem("jwt", token);
    }
  };

  if (authtype === 0) {
    actionButton = (
      <Button
        fullWidth
        variant="contained"
        color="primary"
        disabled={false}
        onClick={(e) => loginAction(e, data)}
      >
        Login
      </Button>
    );
  } else {
    actionButton = (
      <Button
        fullWidth
        variant="contained"
        color="primary"
        onClick={async (e) => {
          const pls = await userRegister(data);
          if (pls.success === false) {
            handleSnack(pls.message, "error");
          } else if (pls.status === 200) {
            loginAction(e, data);
          }
        }}
      >
        Register
      </Button>
    );
  }
  return <> {actionButton}</>;
};

export default Authentication;
