import React from "react";
import Typography from "@material-ui/core/Typography";
import Box from "@material-ui/core/Box";
import TextField from "@material-ui/core/TextField";
import Button from "@material-ui/core/Button";
import Grid from "@material-ui/core/Grid";
import List from "@material-ui/core/List";
import ListItem from "@material-ui/core/ListItem";
import ListItemSecondaryAction from "@material-ui/core/ListItemSecondaryAction";
import ListItemText from "@material-ui/core/ListItemText";
import DeleteIcon from "@material-ui/icons/Delete";
import IconButton from "@material-ui/core/IconButton";
import Link from "@material-ui/core/Link";
import {
  getremoteContacts,
  delContact,
  addContact,
  registerContacts,
} from "./APIHelper";
import { useSnackbar } from "notistack";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import NumberFormat from "react-number-format";

const Contacts = (props) => {
  const { classes, setContacts, contacts } = props;

  const getRemoteContacts = async () => {
    const remoteContactsResponse = await getremoteContacts();
    console.log(remoteContactsResponse);
    if (remoteContactsResponse.success === false) {
      handleSnack(remoteContactsResponse.message, "error");
    } else if (remoteContactsResponse.status === 200) {
      handleSnack("contacts updated from Telstra's Msg API", "success");
      console.log(remoteContactsResponse.data.message.bnum.length);
      if (remoteContactsResponse.data.message.bnum.length !== 0) {
        setContacts(remoteContactsResponse.data.message.bnum);
      }
    }
  };

  const regContacts = async () => {
    try {
      const registerContactsResponse = await registerContacts();
      console.log(registerContactsResponse);
      if (registerContactsResponse.success === false) {
        handleSnack(registerContactsResponse.message, "error");
      } else if (registerContactsResponse.status === 200) {
        handleSnack(
          "locally saved contacts have now been registered with Telstra's Msg API",
          "success"
        );
      }
    } catch (err) {
      console.log(err);
    }
  };

  const deleteContact = async (e, contact) => {
    e.stopPropagation();
    try {
      const delResponse = await delContact(contact);
      if (delResponse.success === false) {
        handleSnack(delResponse.message, "error");
      } else if (delResponse.status === 200) {
        handleSnack(delResponse.data.message, "warning");
        const newContacts = contacts.filter((x) => x !== contact);
        setContacts(newContacts);
      }
    } catch (err) {}
  };

  const { enqueueSnackbar } = useSnackbar();

  const handleSnack = (message, variant) => {
    enqueueSnackbar(`${message}`, { variant });
  };

  const blankNumber = {
    number: "",
  };

  const [number, setNumber] = React.useState(blankNumber);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setNumber({ ...number, [name]: value });
  };

  const resetNumber = () => {
    setNumber(blankNumber);
  };

  const saveNumber = async (e, contact) => {
    const submitedNumber = await addContact(contact);
    if (submitedNumber.success === false) {
      handleSnack(submitedNumber.message, "error");
    } else if (submitedNumber.status === 200) {
      handleSnack(`${contact.number} was successfully added`, "success");
      setContacts(submitedNumber.data.message.bnum);
      resetNumber();
    }
  };

  return (
    <Box m={2}>
      <Typography variant="h6" className={classes.title}>
        Contacts
      </Typography>
      <Typography variant="overline" display="block" gutterBottom>
        For the purpose of this app; this will serve as both contacts &{" "}
        <Link
          target="_blank"
          href="https://dev.telstra.com/content/messaging-api#operation/freeTrialBnumRegister"
          rel="noreferrer"
        >
          B Numbers.
        </Link>
        <br />
        Also worth noting, deleting is impossible on the trial so this is
        technically useless 😊
        <br />
        Be careful when registering the limit is 5 numbers!
      </Typography>
      <form className={classes.root} noValidate autoComplete="off">
        <Grid container justify="flex-end" alignItems="flex-end">
          <Box m={1}>
            <ButtonGroup aria-label="outlined primary button group">
              <Button variant="outlined" onClick={(e) => saveNumber(e, number)}>
                Add
              </Button>
              <Button variant="outlined" onClick={(e) => getRemoteContacts(e)}>
                Get
              </Button>
              <Button variant="outlined" onClick={(e) => regContacts(e)}>
                Register
              </Button>
            </ButtonGroup>
          </Box>
        </Grid>
        <Grid item xs={12}>
          <NumberFormat
            id="contactnum"
            label="new contact"
            name="number"
            fullWidth
            margin="normal"
            customInput={TextField}
            format="+61 (###) ### ###"
            mask=" "
            allowEmptyFormatting
            onChange={handleChange}
            value={number.number}
          />
        </Grid>
      </form>
      <List>
        {contacts.map((contact) => (
          <ListItem divider>
            <ListItemText primary={contact} />
            <ListItemSecondaryAction>
              <IconButton
                edge="end"
                aria-label="delete"
                onClick={(e) => deleteContact(e, contact)}
              >
                <DeleteIcon />
              </IconButton>
            </ListItemSecondaryAction>
          </ListItem>
        ))}
      </List>
    </Box>
  );
};

export default Contacts;
