import React from "react";
import PropTypes from "prop-types";
import AppBar from "@material-ui/core/AppBar";
import Tabs from "@material-ui/core/Tabs";
import Tab from "@material-ui/core/Tab";
import Typography from "@material-ui/core/Typography";
import Box from "@material-ui/core/Box";
import Divider from "@material-ui/core/Divider";
import SecretsForm from "./secretsForm";
import Subscription from "./Subscription";
import Contacts from "./Contacts";
import SendSMS from "./sendSms";
import SmsHistory from "./SmsHistory";

function TabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
    <div
      role="tabpanel"
      hidden={value !== index}
      id={`nav-tabpanel-${index}`}
      aria-labelledby={`nav-tab-${index}`}
      {...other}
    >
      {value === index && (
        <Box p={3}>
          <Typography>{children}</Typography>
        </Box>
      )}
    </div>
  );
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.any.isRequired,
  value: PropTypes.any.isRequired,
};

function a11yProps(index) {
  return {
    id: `nav-tab-${index}`,
    "aria-controls": `nav-tabpanel-${index}`,
  };
}

function LinkTab(props) {
  return (
    <Tab
      component="a"
      onClick={(event) => {
        event.preventDefault();
      }}
      {...props}
    />
  );
}

export default function NavTabs(props) {
  const {
    classes,
    sms,
    setSms,
    sub,
    setSub,
    contacts,
    setContacts,
    sentmsg,
    setSentmsg,
  } = props;
  const [value, setValue] = React.useState(0);

  const handleChange = (event, newValue) => {
    setValue(newValue);
  };

  return (
    <div className={classes.root}>
      <AppBar position="static">
        <Tabs
          variant="fullWidth"
          value={value}
          onChange={handleChange}
          aria-label="nav tabs example"
        >
          <LinkTab label="Messages" href="/messages" {...a11yProps(0)} />
          <LinkTab label="Settings" href="/settings" {...a11yProps(1)} />
        </Tabs>
      </AppBar>
      <TabPanel value={value} index={0}>
        <SendSMS classes={classes} sms={sms} setSms={setSms} />
        <Divider />
        <SmsHistory
          classes={classes}
          sentmsg={sentmsg}
          setSentmsg={setSentmsg}
        />
      </TabPanel>
      <TabPanel value={value} index={1}>
        <SecretsForm classes={classes} />
        <Divider />
        <Subscription classes={classes} sub={sub} setSub={setSub} />
        <Divider />
        <Contacts
          classes={classes}
          contacts={contacts}
          setContacts={setContacts}
        />
      </TabPanel>
    </div>
  );
}
