import React from "react";
import Typography from "@material-ui/core/Typography";
import Box from "@material-ui/core/Box";
import Button from "@material-ui/core/Button";
import Grid from "@material-ui/core/Grid";
import ButtonGroup from "@material-ui/core/ButtonGroup";
import Table from "@material-ui/core/Table";
import TableBody from "@material-ui/core/TableBody";
import TableCell from "@material-ui/core/TableCell";
import TableContainer from "@material-ui/core/TableContainer";
import TableHead from "@material-ui/core/TableHead";
import TableRow from "@material-ui/core/TableRow";
import { getSubLocal, createSub, getSubRemote } from "./APIHelper";
import { useSnackbar } from "notistack";
import Link from "@material-ui/core/Link";

const Subscription = (props) => {
  const { classes, sub, setSub } = props;

  const getSub = async () => {
    const localSubResponse = await getSubLocal();
    setSub(localSubResponse.data.message[0]);
  };

  const createSubcription = async (e) => {
    const createResponse = await createSub();
    if (createResponse.success === false) {
      handleSnack(createResponse.message, "error");
    } else if (createResponse.status === 200) {
      handleSnack(`subscription created!`, "success");
      getSub();
    }
  };

  const getSubcription = async (e) => {
    const getResponse = await getSubRemote();
    if (getResponse.success === false) {
      handleSnack(getResponse.message, "error");
    } else if (getResponse.status === 200) {
      handleSnack(`subscription details received!`, "success");
      getSub();
    }
  };

  const { enqueueSnackbar } = useSnackbar();

  const handleSnack = (message, variant) => {
    enqueueSnackbar(`${message}`, { variant });
  };

  {
    return (
      <Box m={2}>
        <Typography variant="h6" className={classes.title}>
          Subscription
        </Typography>
        <Typography variant="overline" display="block" gutterBottom>
          Assigns you a mobile number; details{" "}
          <Link
            target="_blank"
            href="https://dev.telstra.com/content/messaging-api#tag/Provisioning"
            rel="noreferrer"
          >
            here
          </Link>
        </Typography>
        <Grid
          container
          direction="row"
          justify="flex-end"
          alignItems="baseline"
        >
          <Box m={1}>
            <ButtonGroup aria-label="outlined primary button group">
              <Button variant="outlined" onClick={(e) => createSubcription(e)}>
                Create
              </Button>
              <Button variant="outlined" onClick={(e) => getSubcription(e)}>
                Get status
              </Button>
            </ButtonGroup>
          </Box>
          <TableContainer>
            <Table aria-label="simple table">
              <TableHead>
                <TableRow>
                  <TableCell>Number</TableCell>
                  <TableCell align="right">Active Days</TableCell>
                </TableRow>
              </TableHead>
              <TableBody>
                <TableRow>
                  <TableCell component="th" scope="row">
                    {sub && sub.destinationAddress}
                  </TableCell>
                  <TableCell align="right">{sub && sub.activeDays}</TableCell>
                </TableRow>
              </TableBody>
            </Table>
          </TableContainer>
        </Grid>
      </Box>
    );
  }
};

export default Subscription;
