import React from "react";
import Typography from "@material-ui/core/Typography";
import Box from "@material-ui/core/Box";
import TextField from "@material-ui/core/TextField";
import Button from "@material-ui/core/Button";
import Grid from "@material-ui/core/Grid";
import Link from "@material-ui/core/Link";
import { userSecrets } from "./APIHelper";
import { useSnackbar } from "notistack";

const SecretsForm = (props) => {
  const { classes } = props;
  const blankSecret = {
    clientId: "",
    clientSecret: "",
  };

  const [secret, setSecret] = React.useState(blankSecret);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setSecret({ ...secret, [name]: value });
  };

  const resetSecrets = () => {
    setSecret(blankSecret);
  };

  const saveSecrets = async (e) => {
    const data = {
      clientId: secret.clientId,
      clientSecret: secret.clientSecret,
    };
    const submitedSecrets = await userSecrets(data);

    if (submitedSecrets.success === false) {
      handleSnack(submitedSecrets.message, "error");
    } else if (submitedSecrets.status === 200) {
      handleSnack(`secrets updated`, "success");
      resetSecrets();
    }
  };

  const { enqueueSnackbar } = useSnackbar();

  const handleSnack = (message, variant) => {
    enqueueSnackbar(`${message}`, { variant });
  };

  return (
    <Box m={2}>
      <Typography variant="h6" className={classes.title}>
        Secrets
      </Typography>
      <Typography variant="overline" display="block" gutterBottom>
        These secrets are provided by{" "}
        <Link
          target="_blank"
          href="https://dev.telstra.com/user/me/apps"
          rel="noreferrer"
        >
          Telstra
        </Link>
      </Typography>

      <form className={classes.root} noValidate autoComplete="off">
        <Grid container justify="flex-end" alignItems="flex-end">
          <Box m={1}>
            <Button variant="outlined" onClick={(e) => saveSecrets(e)}>
              Update
            </Button>
          </Box>
        </Grid>

        <TextField
          id="clientId-input"
          label="clientId"
          name="clientId"
          type="password"
          InputLabelProps={{
            shrink: true,
          }}
          onChange={handleChange}
          value={secret.clientId}
        />
        <TextField
          id="clientSecret-input"
          label="clientSecret"
          name="clientSecret"
          type="password"
          InputLabelProps={{
            shrink: true,
          }}
          onChange={handleChange}
          value={secret.clientSecret}
        />
      </form>
    </Box>
  );
};

export default SecretsForm;
