import React from "react";
import Typography from "@material-ui/core/Typography";
import Box from "@material-ui/core/Box";
import TextField from "@material-ui/core/TextField";
import Button from "@material-ui/core/Button";
import Grid from "@material-ui/core/Grid";
import NumberFormat from "react-number-format";
import FormControl from "@material-ui/core/FormControl";
import { sendMessage } from "./APIHelper";
import { useSnackbar } from "notistack";

const SendSMS = (props) => {
  const { classes, sms, setSms } = props;

  const handleChange = (e) => {
    const { name, value } = e.target;
    setSms({ ...sms, [name]: value });
  };

  const sendMsg = async (e) => {
    const data = {
      to: sms.to,
      body: sms.msg,
    };
    const submitedSms = await sendMessage(data);
    if (submitedSms.success === false) {
      handleSnack(submitedSms.message, "error");
    } else if (submitedSms.status === 200) {
      handleSnack("message sent!", "success");
      setSms({ to: "", msg: "" });
    }
  };

  const { enqueueSnackbar } = useSnackbar();

  const handleSnack = (message, variant) => {
    enqueueSnackbar(`${message}`, { variant });
  };

  return (
    <Box m={2}>
      <Typography variant="h6" className={classes.title}>
        Send Messages
      </Typography>

      <FormControl
        className={classes.root}
        noValidate
        autoComplete="off"
        fullWidth
      >
        <Grid container justify="flex-end" alignItems="flex-end">
          <Box m={1}>
            <Button variant="outlined" onClick={(e) => sendMsg(e)}>
              Send
            </Button>
          </Box>
        </Grid>
        <Grid item xs={12}>
          <NumberFormat
            id="recipient"
            label="To:"
            name="to"
            fullWidth
            margin="normal"
            customInput={TextField}
            format="+61 (###) ### ###"
            mask=" "
            allowEmptyFormatting
            onChange={handleChange}
            value={sms.to}
          />
        </Grid>
        <Grid item xs={12}>
          <TextField
            id="message"
            label="Message"
            name="msg"
            fullWidth
            margin="normal"
            inputProps={{ maxLength: 150 }}
            style={{ width: "100%" }}
            multiline
            rows={5}
            rowsMax={5}
            variant="outlined"
            onChange={handleChange}
            value={sms.msg}
          />
        </Grid>
      </FormControl>
    </Box>
  );
};

export default SendSMS;
